###R Workshop with Michel Belyk, November 2014, 2016###

setwd("/Users/belykm/Dropbox/R workshop") #set this to your own working directory
getwd()
load("R workshop.Rdata") #reload data from the previous session
ls() #look at what we've loaded
#################################
###load some built-in datasets###
#################################
data(airquality)
head(airquality)
dim(airquality)

data(ChickWeight)
head(ChickWeight)
dim(ChickWeight)

ls() #let's see what we have to play with

#############
###t tests###
#############
?t.test

###one sample t.tests. Null hypothesis mean is 0 by default
t.test(x= dat1$"treatmentA", alternative="two.sided") #2 tails
t.test(x= dat1$"treatmentA", alternative="greater")   #upper tail
t.test(x= dat1$"treatmentA", alternative="less")      #lower tail

###is treatmentA greater than 10?
t.test(x= dat1$"treatmentA", alternative="greater", mu=10) #good because I synthesized it that way!


###independent sample t.tests. 
#by default this is Welch's two sample t for unqual variance
#can still do students t if you are comfortable assuming equal variance
t.test(x=dat1$"treatmentA", y=dat1$"treatmentB") #Welch's t
t.test(dat1$"treatmentA", dat1$"treatmentB", var.equal=TRUE) #student's t

###dependent sample t.tests
t.test(dat1$"treatmentA", dat1$"treatmentB", paired=TRUE)

###we can save test outputs as objects to explore later
t1<-t.test(dat1$"treatmentA")
names(t1) #these are pieces of information we could retrieve
t1$"statistic"

###take a few minutes to run other tests on these data

#################
###correlation###
#################
?cor
?cor.test

cor(airquality$Wind, airquality$Temp) # returns r value
cor.test(airquality$Wind, airquality$Temp) #significance testing

cor(airquality$Ozone, airquality$Temp) #oops, missing data (NA)!
airquality$Ozone #look at ozone

cor(airquality$Ozone, airquality$Temp, use="complete.obs") #optional argument to omit incomplete cases
cor.test(airquality$Ozone, airquality$Temp) #this command seems to do this by default

#################
###chi squared###
#################
?chisq.test

###synthesize example data.
#Let's test if there are an equal number of chicks at each quartile of weight
head(ChickWeight)
range(ChickWeight$weight)

ch1.O<-vector(length=4) #make an empty matrix
ch1.O

#divide the weight into 4 equal ranages
quarter.range<-(max(ChickWeight$weight) - min(ChickWeight$weight))/4 #one quarter of the range in weights
first.quarter<- quarter.range + min(ChickWeight$weight)
second.quarter<-quarter.range + first.quarter 
third.quarter<- quarter.range + second.quarter
fourth.quarter<-quarter.range + third.quarter

#count the number of chicks in each of four equal ranges
ch1.O[1]<-sum(ChickWeight$weight<first.quarter) #TRUE = 1, FALSE = 0. Sum() therefore counts TRUEs
ch1.O[2]<-sum(ChickWeight$weight>first.quarter & ChickWeight$weight<=second.quarter) #from 119.5 to 204
ch1.O[3]<-sum(ChickWeight$weight>second.quarter & ChickWeight$weight<=third.quarter) #from 204 to 288.5
ch1.O[4]<-sum(ChickWeight$weight>third.quarter)                                      #from 288.5 upwards
ch1.O  #O for Observed

###goodness of fit tests
chisq.test(x=ch1.O) #test whether each weight range is equally probable.

#what if we wanted to test a different null hypothesis
ch1.E<-c(0.4,0.3,0.2,0.1)    #custom table of expected probabilities
ch1.E  #E for Expected
chisq.test(x=ch1.O, p=ch1.E) #test whether observed proabilities differ from expected
            
####contingency table tests
##I'll syntheize some data to test whether weight depends on diet
##don't worry too much about this

ch2.O<-matrix(nrow=2,ncol=4) #make an empty matrix
rownames(ch2.O)<-c("diet1","diet2")
colnames(ch2.O)<-c("bin1","bin2","bin3","bin4")
ch2.O

# count chicks in each range for diet 1
ch2.O[1,1]<-sum(ChickWeight$weight<first.quarter & ChickWeight$Diet==1) 
ch2.O[1,2]<-sum(ChickWeight$weight>first.quarter & ChickWeight$weight<=second.quarter & ChickWeight$Diet==1) 
ch2.O[1,3]<-sum(ChickWeight$weight>second.quarter & ChickWeight$weight<=third.quarter & ChickWeight$Diet==1) 
ch2.O[1,4]<-sum(ChickWeight$weight>third.quarter & ChickWeight$Diet==1)                                      

# count chicks in each range for diet 2
ch2.O[2,1]<-sum(ChickWeight$weight<first.quarter & ChickWeight$Diet==2) 
ch2.O[2,2]<-sum(ChickWeight$weight>first.quarter & ChickWeight$weight<=second.quarter & ChickWeight$Diet==2) 
ch2.O[2,3]<-sum(ChickWeight$weight>second.quarter & ChickWeight$weight<=third.quarter & ChickWeight$Diet==2) 
ch2.O[2,4]<-sum(ChickWeight$weight>third.quarter & ChickWeight$Diet==2)                                      
ch2.O

chisq.test(ch2.O) #p-values may be innacurate with small cell sizes
chisq.test(ch2.O, simulate.p.value=TRUE) #simulation derived p-values are more robust


#######################
###Data to Play With###
#######################
#explore these data and try tests similar to those you usually use on your data
data(cars) #very simple
head(cars)
dim(cars)

data(ChickWeight) #multiple predictors, some unbalanced
head(ChickWeight)
dim(ChickWeight)

data(airquality) #multiple predictors, missing data
head(airquality)
dim(airquality)

save.image("R workshop.Rdata") #save all of the objects in memory

###other packages useful to explore in the future
#Car           alternate ANOVA methods
#lme4          generalized linear mixed models
#mgcv          additive models


