###R Workshop with Michel Belyk, November 2014###


setwd("/Users/belykm/Dropbox/R workshop") #set this to your own working directory
getwd()
load("R workshop.Rdata") 
ls()
##########################
###point and line plots###
##########################
?plot()
?par() #lists many arguments for plotting

head(cars) #peak at some simple data

plot(x=cars$speed, y=cars$dist, type="l") #l for line, better for a time series
plot(x=cars$speed, y=cars$dist, type="p") #p for points

#the same graph with some arguments to tweak the plotting parameters
#see ?par() for an extensive list of parameters
plot(x=cars$speed  #vector of x-coordinates
    ,y=cars$dist   #vector of y-coordinates
    ,type="p"      #type of plot
    ,ylim=c(0,150) #set the range of the y-axis
    ,xlim=c(0,30)  #set the range of thex-axis
    ,ylab="Distance (m)" #label the y axis
    ,xlab="Speed (mph)"  #label the x axis
    ,main="Stopping"     #label the graph
    ,col="red" #plotting colour, google "R colour chart" to see all colours
    ,pch=16    #plotting symbol, google "R pch" for symbol codes
    ,cex=1.25     #size multiplier for symbols, 1 means no change,
    ,cex.axis=1#size multiplier for axes
    ,cex.lab=1.25 #size multiplier for axis labels
    ,cex.main=1.25   #size multiplier for title
)

###add regression line###
cars.lm<-lm(cars$dist~cars$speed)     #define a simple linear model
abline(cars.lm  #plot regression line from linear model
       ,lty=2   #line type 1=solid,2=dash,3=dot,4=dot/dash
       ,lwd=2   #line width multiplier
       ,col="black" #many of the args you just learned will work here too
)
?lines  #also see this function for adding lines to an existing plot
?points #also see this function for adding points to an existing plot

###vary cex, pch & col across points###
#here I make new columns in cars and save my graphical parameters there
head(cars)
cars$cex<-seq(from=0.5,to=1.5, length.out=50) #a sequence of sizes
cars$pch<-rep(c(16,17), times=25) #alternate between symbol 16 & 17, which is circle and triangle
cars$col<-rep(c("black","red"), each=25) #black repeated 25 times, then red
head(cars)
tail(cars)

plot(x=cars$speed   
     ,y=cars$dist   
     ,type="p"     
     ,ylim=c(0,150) 
     ,xlim=c(0,30)  
     ,ylab="Distance (m)" 
     ,xlab="Speed (mph)"    
     ,main="Stopping" 
     ,col=cars$col   #first half black, second half red
     ,pch=cars$pch   #alternating between symbols
     ,cex= cars$cex  #size increasing with speech  
     ,cex.axis=1.25
     ,cex.lab=1.25 
     ,cex.main=1.25
)
abline(cars.lm) 


###a more meaningful example###
#plot all observations above the regression line as black, below as red
residuals(cars.lm) #see the residual error for each point
cars$col2<-"black" #make a new column within cars that just repeats black

head(cars)


#this is some fancy indexing! Let's walk through this one
#find observations with positive residuals, assign them the colour red
cars[residuals(cars.lm)>0,"col2"] <-"red"
head(cars)

plot(x=cars$speed   
     ,y=cars$dist   
     ,type="p"     
     ,ylim=c(0,150) 
     ,xlim=c(0,30)  
     ,ylab="Distance (m)" 
     ,xlab="Speed (mph)"    
     ,main="Stopping" 
     ,col=cars$col2   #black above regression line, red below
     ,pch=16          #back to filled circles
     ,cex= cars$cex    
     ,cex.axis=1.25
     ,cex.lab=1.25 
     ,cex.main=1.25
) #ooh, look how pretty.
abline(cars.lm) 


###add a legend###
?legend

legend("topleft"  #where. could specify xy coordinates instead
      ,legend=c("Poor stopping", "Good stopping") #text to display
      ,text.col=c("red","blue")                   #colours for each symbol
      ,pch= 16                                    #symbols
      ,col= c("red","blue")                       #symbol colours
)

###modify axis###
#the y-axis was looking pretty sprarse
plot(x=cars$speed   
     ,y=cars$dist   
     ,type="p"     
     ,ylim=c(0,150) 
     ,xlim=c(0,30)  
     ,ylab="Distance (m)" 
     ,xlab="Speed (mph)"    
     ,main="Stopping" 
     ,col=cars$col2   
     ,pch=16          
     ,cex= cars$cex    
     ,cex.axis=1.25
     ,cex.lab=1.25 
     ,cex.main=1.25
     ,yaxt="n"        #suppress the automatic y-axis
)
abline(cars.lm)
legend(x="topleft"  #where. could specify xy coordinates instead
       ,legend=c("Poor stopping", "Good stopping") #text to display
       ,text.col=c("red","blue")                  #colours for each symbol
       ,pch= 16                                    #symbols
       ,col= c("red","blue")                      #symbol colours
)
#draw a new axis
?axis()

s


###############
###Bar plots###
###############
?barplot

chick.means1<-with(ChickWeight, tapply(X=weight,INDEX=Diet, FUN=mean))
chick.means1

barplot(height=chick.means1 #the bar height
       ,ylab="Weight"
       ,xlab="Diet"
       ,main="Chicks"
       ,ylim=c(0,175)
       ,col=c("grey91","grey61","grey31","grey1")
)
box() #draw a box around the plot. otherwise the bars are floating


###add error bars###
#this is surprisingly hard
chick.sd1   <-with(ChickWeight, tapply(X=weight,INDEX=Diet, FUN=sd))    #sd for each bar
chick.n1    <-with(ChickWeight, tapply(X=weight,INDEX=Diet, FUN=length))#n for each bar
chick.se1   <-chick.sd1/sqrt(chick.n1)                                  #se for each bar

mp<-barplot(height=chick.means1 #x coordinates of bar midpoints saved as mp
            ,ylab="Weight"
            ,xlab="Diet"
            ,main="Chicks"
            ,ylim=c(0,175)
            ,col=c("grey91","grey61","grey31","grey1") 
)
box()
arrows(x0=mp #x coordinate from which to draw
      ,x1=mp #x coordinate to which to draw
      ,y0=chick.means1+chick.se1 #y coord from which to draw
      ,y1=chick.means1-chick.se1 #y coord to which to draw
      ,angle=90  #draw arrow heads at perpendicular to line
      ,code=3    #1=head at top, 2=head at bottom, 3=both
      ,col="grey50"
      ,lwd=2     #thicker lines since I chose bad colours
)

###recommend some colours
install.packages("RColorBrewer") #install new package
library("RColorBrewer")          #load
?display.brewer.all #shows you some cool colour options
?brewer.pal         #provides codes for those colours

display.brewer.all(n=4,type="qual") #display 4 colours for qualitative distinction
chick.cols<-brewer.pal(n=4, name="Dark2") #I chose Set1
  
barplot(height=chick.means1
            ,ylab="Weight"
            ,xlab="Diet"
            ,main="Chicks"
            ,ylim=c(0,175)
            ,col=chick.cols #our new colours
)
box()
arrows(x0=mp 
       ,x1=mp 
       ,y0=chick.means1+chick.se1 
       ,y1=chick.means1-chick.se1 
       ,angle=90  
       ,code=3    
       ,lwd=2   
)

###Grouped bars
#make a matrix of means & sd
chick.means2<-with(ChickWeight, tapply(X=weight,INDEX=list(Time,Diet), mean))
chick.means2
barplot(height=chick.means2 
        ,ylab="Weight"
        ,xlab="Diet"
        ,main="Chicks"
        ,beside=TRUE  #otherwise stacked bars
)
box() 

#################
###Box&Whisker###
#################

boxplot(weight~Diet      #formula just like lm()
       ,data=ChickWeight #which data to use
       ,ylim=c(0,400)
       ,ylab="Weight"
       ,xlab="Diet"
       ,main="Chicks"
        )

######################
###exporting graphs###
######################
#under the plots tab Export->Save as image or .pdf
#sadly this saves with low resolution (72 dpi by default)
#most journals want figures at 300 dpi or better
#here is some sample code to fix this
#these print to files in your working directory instead of to the screen
#use ? for details

jpeg("SamplePlot1.jpeg", width = 4, height = 4, units = 'in', res = 300)
plot(1,1) #put your beautiful plot here
dev.off()

tiff("SamplePlot2.tiff", width = 4, height = 4, pointsize = 1/300, units = 'in', res = 300)
plot(1,1) 
dev.off()

png("SamplePlot3.png", width = 4, height = 4, units = 'in', res = 300)
plot(1,1) 
dev.off()

pdf("SamplePlot4.pdf", width = 4, height = 4) #.pdf uses vector graphics
plot(1,1) 
dev.off()

postscript("SamplePlot5.eps", width = 480, height = 480) #.eps uses vector graphics
plot(1,1) 
dev.off()

save.image("R workshop.Rdata") #save all of the objects in memory

